@@ -10,9 +10,13 @@
 #define XBLAS_CONFIG_HPP
 
 #define XTENSOR_BLAS_VERSION_MAJOR 0
-#define XTENSOR_BLAS_VERSION_MINOR 12
+#define XTENSOR_BLAS_VERSION_MINOR 13
 #define XTENSOR_BLAS_VERSION_PATCH 0
 
+#ifndef XTENSOR_USE_FLENS_BLAS
+#define HAVE_CBLAS 1
+#endif
+
 #ifndef USE_CXXLAPACK
 #define USE_CXXLAPACK
 #endif
