@@ -9,11 +9,17 @@
 #ifndef XBLAS_CONFIG_CLING_HPP
 #define XBLAS_CONFIG_CLING_HPP
 
-#pragma cling add_library_path("C:/bld/xtensor-blas_1533270243714/_h_env/Library/lib64")
-#pragma cling add_library_path("C:/bld/xtensor-blas_1533270243714/_h_env/Library/lib32")
-#pragma cling add_library_path("C:/bld/xtensor-blas_1533270243714/_h_env/Library/lib")
+#pragma cling add_library_path("C:/bld/xtensor-blas_1534197805412/_h_env/Library/lib64")
+#pragma cling add_library_path("C:/bld/xtensor-blas_1534197805412/_h_env/Library/lib32")
+#pragma cling add_library_path("C:/bld/xtensor-blas_1534197805412/_h_env/Library/lib")
+
+#ifndef XTENSOR_USE_FLENS_BLAS
+
+#define HAVE_CBLAS 1
 
 #pragma cling load("libblas")
 #pragma cling load("liblapack")
 
 #endif
+
+#endif
